from ge_sm.common.secrets import *

#facebook
app_id = os.environ.setdefault('FACEBOOK_APP_ID', '****')
access_token = os.environ.setdefault('FACEBOOK_ACCESS_TOKEN', '****')


secret = os.environ.setdefault('FACEBOOK_APP_SECRET', '****')
app_token = os.environ.setdefault('FACEBOOK_APP_TOKEN', '****')

pg_token = os.environ.setdefault('FACEBOOK_PG_TOKEN', '****')
long_access_token = os.environ.setdefault('FACEBOOK_LONG_ACCESS_TOKEN', '****')
