reportlist = {
    'fb_ads': {'tablename': 'tbl_fb_ads', 'outputcsvloc': '/facebook_code/data_csv/Chaajaa_FB_Ads.csv', 'tablestructure': 'FB_Ads_DataTypes.csv', 'FBPAGE': 'No'},
    'fb_demos': {'tablename': 'tbl_fb_demos', 'outputcsvloc': '/facebook_code/data_csv/Chaajaa_FB_Demos.csv', 'tablestructure': 'FB_Demos_DataTypes.csv', 'FBPAGE': 'Yes'},
    'fb_pages_day': {'tablename': 'tbl_fb_pages_day', 'outputcsvloc': '/facebook_code/data_csv/Chaajaa_FB_Pages_day.csv', 'tablestructure': 'FB_Pages_DataTypes.csv', 'FBPAGE': 'Yes'},
    'fb_pages_week': {'tablename': 'tbl_fb_pages_week', 'outputcsvloc': '/facebook_code/data_csv/Chaajaa_FB_Pages_week.csv', 'tablestructure': 'FB_Pages_DataTypes.csv', 'FBPAGE': 'Yes'},
    'fb_pages_days_28': {'tablename': 'tbl_fb_pages_days_28', 'outputcsvloc': '/facebook_code/data_csv/Chaajaa_FB_Pages_days_28.csv', 'tablestructure': 'FB_Pages_DataTypes.csv', 'FBPAGE': 'Yes'},
    'fb_posts': {'tablename': 'tbl_fb_posts', 'outputcsvloc': '/facebook_code/data_csv/Chaajaa_FB_Posts.csv', 'tablestructure': 'FB_Posts_DataTypes.csv', 'FBPAGE': 'No'},
    'yt_channels': {'tablename': 'tbl_yt_channels', 'outputcsvloc': '/youtube_code/data_csv/Chaajaa_YT_Channels.csv', 'tablestructure': 'YT_Channels_DataTypes.csv', 'FBPAGE': 'No'},
    'yt_demos' :{'tablename': 'tbl_yt_demos', 'outputcsvloc': '/youtube_code/data_csv/Chaajaa_YT_Demos.csv', 'tablestructure': 'YT_Demos_DataTypes.csv', 'FBPAGE': 'No'},
    'yt_video':{'tablename': 'tbl_yt_videos', 'outputcsvloc': '/youtube_code/data_csv/Chaajaa_YT_Videos.csv', 'tablestructure': 'YT_Videos_DataTypes.csv', 'FBPAGE': 'No'},
    'ga_user_pages_C':{'tablename': 'tbl_ga_user_pages_c', 'outputcsvloc': '/google_analytics_code/data_csv/Chaajaa_GA_User_Pages_C.csv', 'tablestructure': 'GA_User_Pages_C_DataTypes.csv', 'FBPAGE': 'No'},
    'ga_user_pages_CK':{'tablename': 'tbl_ga_user_pages_ck', 'outputcsvloc': '/google_analytics_code/data_csv/Chaajaa_GA_User_Pages_CK.csv', 'tablestructure': 'GA_User_Pages_CK_DataTypes.csv', 'FBPAGE': 'No'},
    'ga_user_pages_CW':{'tablename': 'tbl_ga_user_pages_cw', 'outputcsvloc': '/google_analytics_code/data_csv/Chaajaa_GA_User_CPages_W.csv', 'tablestructure': 'GA_User_Pages_CW_DataTypes.csv', 'FBPAGE': 'No'},
    'ga_user_pages_CKW':{'tablename': 'tbl_ga_user_pages_ckw', 'outputcsvloc': '/google_analytics_code/data_csv/Chaajaa_GA_User_Pages_CKW.csv', 'tablestructure': 'GA_User_Pages_CKW_DataTypes.csv', 'FBPAGE': 'No'},
    'ga_user_events_C':{'tablename': 'tbl_ga_user_events_c', 'outputcsvloc': '/google_analytics_code/data_csv/Chaajaa_GA_User_Events_C.csv', 'tablestructure': 'GA_User_Events_C_DataTypes.csv', 'FBPAGE': 'No'},
    'ga_user_events_CK':{'tablename': 'tbl_ga_user_events_ck', 'outputcsvloc': '/google_analytics_code/data_csv/Chaajaa_GA_User_Events_CK.csv', 'tablestructure': 'GA_User_Events_CK_DataTypes.csv', 'FBPAGE': 'No'},
    'ga_user_events_CW':{'tablename': 'tbl_ga_user_events_cw', 'outputcsvloc': '/google_analytics_code/data_csv/Chaajaa_GA_User_Events_CW.csv', 'tablestructure': 'GA_User_Events_CW_DataTypes.csv', 'FBPAGE': 'No'},
    'ga_user_events_CKW':{'tablename': 'tbl_ga_user_events_ckw', 'outputcsvloc': '/google_analytics_code/data_csv/Chaajaa_GA_User_Events_CKW.csv', 'tablestructure': 'GA_User_Events_CKW_DataTypes.csv', 'FBPAGE': 'No'},
    'ga_signed_up':{'tablename': 'tbl_ga_signup', 'outputcsvloc': '/google_analytics_code/data_csv/SignUp.csv', 'tablestructure': 'GA_SignUp_DataTypes.csv', 'FBPAGE': 'No'}}


